@@ -13,9 +13,9 @@ from PySide import QtDeclarative
 class cubetimer():
 	def __init__(self):
 
-		#Oberfläche und Instanzierungen für QML2Py Funktionen		
+		#Oberfläche und Instanzierungen für QML2Py Funktionen
 		self.view = QtDeclarative.QDeclarativeView()
-		self.view.setSource(QtCore.QUrl('QML/UI.qml'))	
+		self.view.setSource(QtCore.QUrl('QML/UI.qml'))
 		self.root = self.view.rootObject()
 
 		# instantiate the Python object
@@ -24,9 +24,9 @@ class cubetimer():
     		# expose the object to QML
 		self.context = self.view.rootContext()
 		self.context.setContextProperty("pyfunc", self.pyfunc)
-		
-		#self.view.setAttribute(Qt.WA_Maemo5PortraitOrientation, True)
-	
+
+		self.view.setAttribute(Qt.WA_Maemo5PortraitOrientation, True)
+
 
 		#Buttons der UI
 		self.scramblebutton = self.root.findChild(QtCore.QObject,"button1")
@@ -42,7 +42,7 @@ class cubetimer():
 		self.stopwatchbutton.clicked.connect(self.waittime)
 
 		#Es könnte der Ende Button des Menü's auch wie oben realisiert werden, aktuell wird pyfunc.ende() aus QML heraus angesprochen!
-		#self.exitbutton = self.root...		
+		#self.exitbutton = self.root...
 
 		#Variable ob der Timer läuft
 		self.timer_on = False
@@ -51,7 +51,7 @@ class cubetimer():
 		#Variable für Timer (hochzählen), Timer2 (runterzählen)
 		self.timer = QtCore.QTimer()
 		self.timer2 = QtCore.QTimer()
-		#Variable für Update/Unterbrecher damit UI weiter reagiert + Zeit in ms 
+		#Variable für Update/Unterbrecher damit UI weiter reagiert + Zeit in ms
         	self.timer.setInterval(10)
 		self.timer2.setInterval(500)
 		#Gibt an was ausgeführt wird wenn der Interval abgelaufen ist!
@@ -62,13 +62,13 @@ class cubetimer():
 
 		self.inspectionmode = None
 		self.stopwatchmode = None
-		
+
 #--------------------------------------------------------------------------------------------------
 
-		#Setting von ersten Werten auf Oberfläche Zeiten, Stopwatch-Modus, Inspection-Time		
+		#Setting von ersten Werten auf Oberfläche Zeiten, Stopwatch-Modus, Inspection-Time
 		self.settings()
 		self.scrambler()
-		
+
 #--------------------------------------------------------------------------------------------------
 	#Funktionen des Programms/Python-Logik
 
@@ -103,7 +103,7 @@ class cubetimer():
 		record = self.time_transformer(rec)
 		average = self.time_transformer(ave)
 		last = self.time_transformer(last)
-		
+
 		#Schreiben der Zeitwerte
 		self.root.record_time("best: %s" % record)
 		self.root.average_time("average: %s" % average)
@@ -119,14 +119,14 @@ class cubetimer():
 		seconds = ms % 60
 		ms /= 60
 		minutes = ms % 60
-		
+
 		ms = '%02d:%02d:%02d' % (minutes, seconds, hundredthseconds)
 		return ms
 
 #--------------------------------------------------------------------------------------------------
-	
+
 	# Notationen werden zufällig gezogen und dann auf die ersten beiden Linien geschrieben - die 2 Linien kommen durch Schriftgröße/Platz.
-	# Es können auch andere Notationen, oder zusätzliche in die Liste eingetragen werden! ;)	
+	# Es können auch andere Notationen, oder zusätzliche in die Liste eingetragen werden! ;)
 	def scrambler(self):
 		notations = ["U  ","U'  ","U2  ","D  ","D'  ","D2  ","R  ","R'  ","R2  ","L  ","L'  ","L2  ","F  ","F'  ","F2  ","B  ","B'  ","B2  "]
 		scrambled = []
@@ -151,7 +151,7 @@ class cubetimer():
 		#Nullen des Timers beim Start sowie beim drücken des Reload-Button
 		self.root.timerUpdate("00:00:00")
 
-#--------------------------------------------------------------------------------------------------	
+#--------------------------------------------------------------------------------------------------
 
 	#Thanks to Boris Pohlers, for help with the stopwatch and hint to QTimer.
 	#Timer starten/stoppen!
@@ -168,15 +168,15 @@ class cubetimer():
 				self.timer2.start()
 		else:
 			self.timer_start_stop()
-			
+
 
 	def timer_start_stop(self):
 		if self.timer_on == False:
-			self.timer_on = True		
+			self.timer_on = True
 			self.zeit.start()
         		self.timer.start()
 			return self.timer_on
-	
+
 		elif self.timer_on == True:
 			self.timer_on = False
 			self.total_time = self.total_time + self.zeit.elapsed()
@@ -195,25 +195,25 @@ class cubetimer():
 		seconds = milliseconds % 60
 		milliseconds /= 60
 		minutes = milliseconds % 60
-		
-        	self.root.timerUpdate('%02d:%02d:%02d' % (minutes, seconds, hundredthseconds))	
+
+        	self.root.timerUpdate('%02d:%02d:%02d' % (minutes, seconds, hundredthseconds))
 
 #--------------------------------------------------------------------------------------------------
 
 	def save_times(self, zeit):
-		#Die Zeiten sollen natürlich nicht gespeichert werden, wenn der User im Stopuhr Modus ist!		
+		#Die Zeiten sollen natürlich nicht gespeichert werden, wenn der User im Stopuhr Modus ist!
 		if self.stopwatchmode == False:
 			#Laden der gespeicherten Daten
 			f = open("/home/user/.config/cubetimer.cfg")
 			l = pickle.load(f)
 
 			#Einlesen der Zeiten und Berechnung! "last" ist die letzte Zeit, der Durchschnitt ergibt sich aus allen jemals gespielten Zeiten.
-			#Diese werden einfach aufaddiert in "averagetimeaddion" geteilt durch die Anzahl aller je gespielten Spiele "averagedivider".	
+			#Diese werden einfach aufaddiert in "averagetimeaddion" geteilt durch die Anzahl aller je gespielten Spiele "averagedivider".
 			l["last"] = zeit
 			l["average"] = ((l["averagetimeaddion"]+int(zeit))/l["averagedivider"])
 			l["averagetimeaddion"] = (l["averagetimeaddion"]+int(zeit*1.0))
 			l["averagedivider"] += 1
-		
+
 			# Kontrolle ob neue Zeit auch neuer Rekord ist!
 			if l["record"] == 0:
 				l["record"] = zeit
@@ -227,7 +227,7 @@ class cubetimer():
 
 		else:
 			pass
-		
+
 #--------------------------------------------------------------------------------------------------
 
 	def reset(self):
@@ -252,13 +252,13 @@ class cubetimer():
 		l = pickle.load(f)
 
 		l["stopwatch"] = self.stopwatchmode
-		
+
 		#Speichern der Daten
 		f = open("/home/user/.config/cubetimer.cfg", "w")
 		pickle.dump(l,f)
 
 #--------------------------------------------------------------------------------------------------
-	
+
 	def waittime(self):
 		if self.inspectionmode == False:
 			self.inspectionmode = True
@@ -272,7 +272,7 @@ class cubetimer():
 		l = pickle.load(f)
 
 		l["inspection"] = self.inspectionmode
-		
+
 		#Speichern der Daten
 		f = open("/home/user/.config/cubetimer.cfg", "w")
 		pickle.dump(l,f)
@@ -286,7 +286,7 @@ class cubetimer():
 		seconds = milliseconds % 60
 		milliseconds /= 60
 		minutes = milliseconds % 60
-		
+
 		if waittime-self.zeit.elapsed() <= 0:
 			print "STOP"
 			self.timer2.stop()
